﻿using System;
using System.Collections.Generic;
using Celeste.Mod.Entities;
using Microsoft.Xna.Framework;
using Monocle;

namespace Celeste.Mod.SusanHelper
{
	[CustomEntity("SusanHelper/ColorField")]
	[Tracked]
	public class ColorField : Solid
	{

		private ColorFieldRenderer renderer = new ColorFieldRenderer();

		public enum Directions
		{
			Up,
			Down,
			Left,
			Right
		}

		public Color color;

		private bool trackingSet = false;


		public ColorField(Vector2 position, float width, float height, string colorName, float alpha)
			: base(position, width, height, safe: false)
		{
			color = Calc.HexToColor(colorName) * Math.Min(Math.Abs(alpha), 1f);

			Collidable = false;

		}

		public ColorField(EntityData data, Vector2 offset)
			: this(data.Position + offset, data.Width, data.Height, data.Attr("color", "000000"), data.Float("alpha", 0.5f))
		{
		}

		public override void Awake(Scene scene)
		{
			base.Awake(scene);

			if (!trackingSet)
			{
				// COLOURSOFNOISE: This should ideally be done with a hook but eh whatever
				scene.Add(renderer = new ColorFieldRenderer());
				foreach (ColorField barrier in Scene.Tracker.GetEntitiesCopy<ColorField>())
				{
					barrier.renderer = renderer;
					renderer.Track(barrier, SceneAs<Level>());
					barrier.trackingSet = true;
				}
			}
		}

        public override void Removed(Scene scene)
		{
			base.Removed(scene);
			renderer.Untrack(this);
		}
	}
}